
*First we calculate propensity scores within each sample group to match hospitals

local glevel emcare emcare_high emcare_low teamhealth
foreach f of local glevel {

use ${dd}\ed_episodes_cleaned.dta, clear

*fixing AHA indicators to zero or one
foreach var of varlist aha_mapp* {
	replace `var'=0 if `var'==2
	}

*Only need one year for AHA
bysort aha: gen first_inst=_n==1
keep if first_inst==1

*Use correct sample
merge 1:1 aha using ${sc}/group_levels/`f'_fullsample.dta
	keep if _merge==3
	drop _merge

*renaming entry indicator for regressions
if ("`f'"=="emcare_high" | "`f'"=="emcare_low" | "`f'"=="emcare") {
replace emcare_entry_ind=0 if emcare_entry_ind==.
rename emcare_entry_ind entry_indicator
}

if ("`f'"=="teamhealth_high" | "`f'"=="teamhealth_low" | "`f'"=="teamhealth") {
replace teamhealth_entry_ind=0 if teamhealth_entry_ind==.
rename teamhealth_entry_ind entry_indicator
}

*Logit regression of hospital beds, technology, non-profit status, and the ^2, ^3, and ^4
*of beds and technology
gen aha_hospbd2=aha_hospbd^2
gen aha_hospbd3=aha_hospbd^3
gen aha_hospbd4=aha_hospbd^4
gen aha_techtotal2=aha_techtotal^2
gen aha_techtotal3=aha_techtotal^3
gen aha_techtotal4=aha_techtotal^4

*logit of entry on hospital characteristics
logit entry_indicator aha_hospbd aha_hospbd2 aha_hospbd3 aha_hospbd4 aha_techtotal aha_techtotal2 aha_techtotal3 aha_techtotal4 aha_c_np 
predict ps

*Calculate nearest neighbor

encode(state), gen(state_code)
gen state_code_num=state_code

*Ensuring that propensity scores can only be matched within states
gen ps2=state_code_num*10+ps
psmatch2 entry_indicator ,noreplacement pscore(ps2) logit neighbor(1)

*Identifying matches
gen pair = _id if _treated==0
replace pair = _n1 if _treated==1
bysort pair: egen paircount = count(pair)
drop if paircount !=2

keep aha

save ${sc}/datasets/`f'_neighbor.dta, replace 

}

*****************************************

*Now we run regressions using full sample, state sample, and propensity sample
local glevel emcare_low emcare_high
foreach f of local glevel {

use ${dd}\ed_episodes_cleaned.dta, clear
sort year_start bi_ind
egen bigroup=group(year_start bi_ind)
egen mogroup=group(year_start month_start)

estimates clear

*use the proper sample
merge m:1 aha using ${sc}/group_levels/`f'_fullsample.dta
keep if _merge==3
drop _merge

*episodes per year
bysort aha year_start: gen ep_counts=_N

*define the entry
if ("`f'"=="emcare_high" | "`f'"=="emcare_low" | "`f'"=="emcare") {
rename emcare_entry entry_marker
}

if ("`f'"=="teamhealth_high" | "`f'"=="teamhealth_low" | "`f'"=="teamhealth") {
rename teamhealth_entry entry_marker
}

*OON rates for high/low hospitals 
foreach var of varlist oon_ind {

*Version 1 (all other hospitals included)
eststo: areg `var' i.mogroup entry_marker pat_female i.pat_age i.pat_race charind, absorb(aha) vce(cluster aha)
estadd ysumm
esttab using ${o}/final_tables/`f'_oon_propensity.csv, stats(ymean ysd N) replace se ///
	nogaps drop(_cons *mogroup* *pat_age* *pat_race* pat_female charind) r2 noparentheses starlevels(* 0.10 ** 0.05 *** 0.01)

preserve

*Version 2 (only keep states where entry occurs)
if ("`f'"=="emcare_high" | "`f'"=="emcare_low" | "`f'"=="emcare") {
keep if state_mark=="emcare"
}

if ("`f'"=="teamhealth_high" | "`f'"=="teamhealth_low" | "`f'"=="teamhealth") {
keep if state_mark=="teamhealth"
}

eststo: areg `var' i.mogroup entry_marker pat_female i.pat_age i.pat_race charind, absorb(aha) vce(cluster aha)
estadd ysumm
esttab using ${o}/final_tables/`f'_oon_propensity.csv, stats(ymean ysd N) replace se ///
	nogaps drop(_cons *mogroup* *pat_age* *pat_race* pat_female charind) r2 noparentheses starlevels(* 0.10 ** 0.05 *** 0.01)

restore
preserve

*Version 3 (nearest neighbors from propensity score matching)
merge m:1 aha using ${sc}/datasets/`f'_neighbor.dta
keep if _merge==3

eststo: areg `var' i.mogroup entry_marker pat_female i.pat_age i.pat_race charind, absorb(aha) vce(cluster aha)
estadd ysumm
esttab using ${o}/final_tables/`f'_oon_propensity.csv, stats(ymean ysd N) replace se ///
	nogaps drop(_cons *mogroup* *pat_age* *pat_race* pat_female charind) r2 noparentheses starlevels(* 0.10 ** 0.05 *** 0.01)

restore
	}

}












